@@ -318,7 +318,11 @@ Chat.Ind <- function(x, m){
   f0.hat <- ifelse(f2 == 0, (n - 1) / n * f1 * (f1 - 1) / 2, (n - 1) / n * f1 ^ 2/ 2 / f2)  #estimation of unseen species via Chao1
   A <- ifelse(f1>0, n*f0.hat/(n*f0.hat+f1), 1)
   Sub <- function(m){
-    if(m < n) out <- 1-sum(x / n * exp(lchoose(n - x, m)-lchoose(n - 1, m)))
+    #if(m < n) out <- 1-sum(x / n * exp(lchoose(n - x, m)-lchoose(n - 1, m)))
+    if(m < n) {
+      xx <- x[(n-x)>=m]
+      out <- 1-sum(xx / n * exp(lgamma(n-xx+1)-lgamma(n-xx-m+1)-lgamma(n)+lgamma(n-m)))
+    }
     if(m == n) out <- 1-f1/n*A
     if(m > n) out <- 1-f1/n*A^(m-n+1)
     out
@@ -348,7 +352,11 @@ Chat.Sam <- function(x, t){
   Q0.hat <- ifelse(Q2 == 0, (nT - 1) / nT * Q1 * (Q1 - 1) / 2, (nT - 1) / nT * Q1 ^ 2/ 2 / Q2)  #estimation of unseen species via Chao2
   A <- ifelse(Q1>0, nT*Q0.hat/(nT*Q0.hat+Q1), 1)
   Sub <- function(t){
-    if(t < nT) out <- 1 - sum(y / U * exp(lchoose(nT - y, t) - lchoose(nT - 1, t)))
+    if(t < nT) {
+      yy <- y[(nT-y)>=t]
+      out <- 1 - sum(yy / U * exp(lgamma(nT-yy+1)-lgamma(nT-yy-t+1)-lgamma(nT)+lgamma(nT-t)))     
+    }
+    #if(t < nT) out <- 1 - sum(y / U * exp(lchoose(nT - y, t) - lchoose(nT - 1, t)))
     if(t == nT) out <- 1 - Q1 / U * A
     if(t > nT) out <- 1 - Q1 / U * A^(t - nT + 1)
     out
@@ -505,25 +513,30 @@ iNEXT.Sam <- function(Spec, t=NULL, q=0, endpoint=2*max(Spec), knots=40, se=TRUE
 #
 #
 ###############################################
-#' iNterpolation and EXTrapolation of Hill number
+#' iNterpolation and EXTrapolation of Hill numbers
 #' 
-#' \code{iNEXT} Estimation of interpolation and extrapolation of Hill number with order q
+#' \code{iNEXT}: Interpolation and extrapolation of Hill number with order \code{q}.
 #' 
-#' @param x a vector of species abundance or incidence frequency. If \code{datatype = "incidence"}, then the input format of first entry should be total number of sampling units, and followed by species incidence frequency. 
-#' Note that in iNEXT version 2.0, the input arguments allow the class of \code{\link{numeric}}, \code{\link{matrix}}, \code{\link{data.frame}} (species by sites), or \code{\link{list}}.
-#' @param q a numeric value, the order of Hill number .
-#' @param datatype the data type of input data. That is individual-based abundance data (\code{datatype = "abundance"}) or sample-based incidence data (\code{datatype = "incidence"}).
-#' @param size an integer vector of rarefaction/extrapolation sample size (number of individuals or sampling units), default is NULL. If \code{size} is not be specified, it would compute rarefaction/extrapolation by endpoint and knots.
-#' @param endpoint a integer of sample size that is the endpoint for rarefaction/extrapolation. Default is double reference sample size.
-#' @param knots a number of knots (say K, default is 40) specifying separate sample size between 1 and \code{endpoint}. 
-#' If \code{endpoint} is smaller than reference sample size, then \code{iNEXT()} compute rarefaction part only and divided by approximately equall spaced K. 
-#' If \code{endpoint} os larger than reference sample size, then \code{iNEXT()} will compute approximately K/2 equally spaced for rarefaction part and divided extrapolation part as approximately K/2 equally spaced between reference sample size and \code{endpoint}.
-#' @param se calculate bootstrap standard error and show 95\% confidence interval; default is TRUE.
-#' @param nboot the number of bootstrap resampling times, default is 50.
-#' @return a list of interpolation and extrapolation Hill number with specific order q (qD) and sample coverage (SC)
+#' @param x a matrix, data.frame (species by sites), or list of species abundances or incidence frequencies. If \code{datatype = "incidence"}, then the first entry of the input data must be total number of sampling units in each column or list. 
+#' @param q a numeric value specifying the diversity order of Hill numbers.
+#' @param datatype data type of input data: individual-based abundance data (\code{datatype = "abundance"}) or 
+#' sampling-unit-based incidence data (\code{datatype = "incidence"}).
+#' @param size an integer vector of sample sizes (number of individuals or sampling units) for which diversity estimates will be computed. 
+#' If NULL, then diversity estimates will be computed for those sample sizes determined by the specified/default \code{endpoint} and \code{knots} .
+#' @param endpoint an integer specifying the sample size that is the \code{endpoint} for rarefaction/extrapolation. 
+#' If NULL, then \code{endpoint} \code{=} double reference sample size.
+#' @param knots an integer specifying the number of equally-spaced \code{knots} (say K, default is 40) between size 1 and the \code{endpoint};
+#' each knot represents a particular sample size for which diversity estimate will be calculated.  
+#' If the \code{endpoint} is smaller than the reference sample size, then \code{iNEXT()} computes only the rarefaction esimates for approximately K evenly spaced \code{knots}. 
+#' If the \code{endpoint} is larger than the reference sample size, then \code{iNEXT()} computes rarefaction estimates for approximately K/2 evenly spaced \code{knots} between sample size 1 and the reference sample size, and computes extrapolation estimates for approximately K/2 evenly spaced \code{knots} between the reference sample size and the \code{endpoint}.
+#' @param se a logical variable to calculate the bootstrap standard error and 95\% confidence interval.
+#' @param nboot an integer specifying the number of replications.
+#' @return a list of three objects: \code{$DataInfo} for summarizing data information; 
+#' \code{$iNextEst} for showing diversity estimates for rarefied and extrapolated samples along with related statistics;
+#' and \code{$AsyEst} for showing asymptotic diversity estimates along with related statistics.  
 #' @examples
 #' data(spider)
-#' z <- iNEXT(spider, q=0, datatype="abundance")
+#' iNEXT(spider, q=0, datatype="abundance")
 #' 
 #' data(ant)
 #' iNEXT(ant$h500m, q=1, datatype="incidence", size=round(seq(10, 500, length.out=20)), se=FALSE)
@@ -566,7 +579,7 @@ iNEXT <- function(x, q=0, datatype="abundance", size=NULL, endpoint=NULL, knots=
     index <- rbind(as.matrix(ChaoSpecies(x, datatype)), 
                    as.matrix(ChaoEntropy(x, datatype, transform=TRUE)),
                    as.matrix(EstSimpson(x, datatype, transform=TRUE)))
-    rownames(index) <- c("Species Richness", "Exponential Entropy", "Inverse Simpson")
+    rownames(index) <- c("Species Richness", "Shannon diversity", "Simpson diversity")
     
   }else if(class(x)=="matrix" | class(x)=="data.frame"){
     out <- apply(as.matrix(x), 2, function(x){
@@ -579,7 +592,7 @@ iNEXT <- function(x, q=0, datatype="abundance", size=NULL, endpoint=NULL, knots=
     arr[2,,] <- t(as.matrix(ChaoEntropy(x, datatype, transform=TRUE)))
     arr[3,,] <- t(as.matrix(EstSimpson(x, datatype, transform=TRUE)))  
     dimnames(arr)[[3]] <- names(x)
-    dimnames(arr)[[1]] <- c("Species Richness", "Exponential Entropy", "Inverse Simpson")
+    dimnames(arr)[[1]] <- c("Species richness", "Shannon diversity", "Simpson diversity")
     dimnames(arr)[[2]] <- c("Observed", "Estimator", "Est_s.e.", "95% Lower", "95% Upper")
     index <- ftable(arr, row.vars = c(3,1))
     
@@ -595,17 +608,17 @@ iNEXT <- function(x, q=0, datatype="abundance", size=NULL, endpoint=NULL, knots=
     arr[2,,] <- t(as.matrix(ChaoEntropy(x, datatype, transform=TRUE)))
     arr[3,,] <- t(as.matrix(EstSimpson(x, datatype, transform=TRUE)))  
     dimnames(arr)[[3]] <- names(x)
-    dimnames(arr)[[1]] <- c("Species Richness", "Exponential Entropy", "Inverse Simpson")
+    dimnames(arr)[[1]] <- c("Species richness", "Shannon diversity", "Simpson diversity")
     dimnames(arr)[[2]] <- c("Observed", "Estimator", "Est_s.e.", "95% Lower", "95% Upper")
     index <- ftable(arr, row.vars = c(3,1))
   }else{
-    stop("invlid class of x, x should be a object of numeric, matrix, data.frame, or list")
+    stop("invalid class of x, x should be a object of numeric, matrix, data.frame, or list")
   }
   
   info <- DataInfo(x, datatype)
   
   
-  z <- list("DataInfo"=info, "BasicIndex"=index,"Accumulation"=out)
+  z <- list("DataInfo"=info, "iNextEst"=out, "AsyEst"=index)
   class(z) <- c("iNEXT")
   return(z)
 }
@@ -618,7 +631,7 @@ iNEXT <- function(x, q=0, datatype="abundance", size=NULL, endpoint=NULL, knots=
 # 
 # \code{EstDis} Estimation of the rank of species relative abundance distribution or detection probability to obtain bootstrap s.e.
 # 
-# @param x a vector of species abundance or incidence frequency. If \code{datatype = "incidence"}, then the input format of first entry should be total number of sampling units, and followed by species incidence frequency.
+# @param x a vector of species abundances or incidence frequencies. If \code{datatype = "incidence"}, then the input format of first entry should be total number of sampling units, and followed by species incidence frequency.
 # @param datatype the data type of input data. That is individual-based abundance data (\code{datatype = "abundance"}) or sample-based incidence data (\code{datatype = "incidence"}).
 # @return a vector of the rank of estimated relative abundance distribution or detection probability
 # @examples 
@@ -638,39 +651,48 @@ EstDis <- function(x, datatype=c("abundance", "incidence")){
 #
 #
 ###############################################
-#' ggplot2 extension for an iNEXT Object
+#' ggplot2 extension for an iNEXT object
 #' 
-#' \code{ggiNEXT} the \code{\link{ggplot2}} extension for \code{\link{iNEXT}} Object
-#' @param x a \code{iNEXT} object computed by \code{\link{iNEXT}}
-#' @param type three different plotting \code{type = c(1, 2, 3)}; \code{1} means to plot number of individuals or number of samples to diversity;
-#'              \code{2} means to plot number of individuals or number of samples to sample coverage; and \code{3} means to plot sample coverage to diversity.                 
-#' @param se display confidence interval around estimated accumulation curve
-#' @param facet.var display subsets of the dataset in different panels with four choices: \code{facet.var = c("none", "order", "site", "both")} where \code{"none"} means do not split any lay out panels in a grid; \code{"order"} means split lay out panels by different orders q; \code{"site"} means split lay out panels by different sites; and \code{"both"} means split lay out panels by order and sites.              
-#' @param color.var display subsets of the dataset in different colors with four choices: \code{color.var = c("none", "order", "site", "both")} where \code{"none"} means do not split any color; \code{"order"} means split colors by different orders q; \code{"site"} means split colors by different sites; and \code{"both"} means split colors by order and sites.  
-#' @return a ggplot object
+#' \code{ggiNEXT}: the \code{\link{ggplot2}} extension for \code{\link{iNEXT}} object to plot sample-size- and coverage-based rarefaction/extrapolation curves along with a bridging sample completeness curve.
+#' @param x an \code{iNEXT} object computed by \code{\link{iNEXT}}.
+#' @param type three types of plots: sample-size-based rarefaction/extrapolation curve (\code{type = 1}); 
+#' sample completeness curve (\code{type = 2}); coverage-based rarefaction/extrapolation curve (\code{type = 3}).                 
+#' @param se a logical variable to display confidence interval around the estimated sampling curve.
+#' @param facet.var create a separate plot for each value of a specified variable: 
+#'  no separation \cr (\code{facet.var="none"}); 
+#'  a separate plot for each diversity order (\code{facet.var="order"}); 
+#'  a separate plot for each site (\code{facet.var="site"}); 
+#'  a separate plot for each combination of order x site (\code{facet.var="both"}).              
+#' @param color.var create curves in different colors for values of a specified variable:
+#'  all curves are in the same color (\code{color.var="none"}); 
+#'  use different colors for diversity orders (\code{color.var="order"}); 
+#'  use different colors for sites (\code{color.var="site"}); 
+#'  use different colors for combinations of order x site (\code{color.var="both"}).  
+#' @param grey a logical variable to display grey and white ggplot2 theme. 
+#' @return a ggplot2 object
 #' @examples
 #' data(spider)
-#' # single abundance-based data
+#' # single-assemblage abundance data
 #' out1 <- iNEXT(spider$Girdled, q=0, datatype="abundance")
-#' ggiNEXT(x=out1, type=1)
-#' ggiNEXT(x=out1, type=2)
-#' ggiNEXT(x=out1, type=3)
+#' ggiNEXT(out1, type=1)
+#' ggiNEXT(out1, type=2)
+#' ggiNEXT(out1, type=3)
 #' 
 #'\dontrun{
-#' # single incidence-based data with multiple order q
+#' # single-assemblage incidence data with three orders q
 #' data(ant)
 #' size <- round(seq(10, 500, length.out=20))
-#' y <- iNEXT(ant$h500m, q=c(0,1,2), datatype="incidence", size=size, se=FALSE)
-#' ggiNEXT(y, se=FALSE)
+#' out2 <- iNEXT(ant$h500m, q=c(0,1,2), datatype="incidence", size=size, se=FALSE)
+#' ggiNEXT(out2, se=FALSE, color.var="order")
 #' 
-#' # multiple abundance-based data with multiple order q
-#' z <- iNEXT(spider, q=c(0,1,2), datatype="abundance")
-#' ggiNEXT(z, facet.var="site", color.var="order")
-#' ggiNEXT(z, facet.var="both", color.var="both")
+#' # multiple-assemblage abundance data with three orders q
+#' out3 <- iNEXT(spider, q=c(0,1,2), datatype="abundance")
+#' ggiNEXT(out3, facet.var="site", color.var="order")
+#' ggiNEXT(out3, facet.var="both", color.var="both")
 #'}
 #' @export
 
-ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
+ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="site", grey=FALSE){
   if(class(x) != "iNEXT") 
     stop("invalid object class")
   TYPE <-  c(1, 2, 3)
@@ -688,14 +710,17 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
   if(facet.var=="order") color.var <- "site"
   if(facet.var=="site") color.var <- "order"
   
-  y <- method <- site <- y.lwr <- y.upr <- NULL
+  y <- method <- site <- shape <- y.lwr <- y.upr <- NULL
   site <<- NULL
-  z <- x$Accumulation
+  z <- x$iNextEst
   if(class(z) == "list"){
-    z <- data.frame(do.call("rbind", z) ,site=rep(names(z), sapply(z, nrow)))
+    z <- data.frame(do.call("rbind", z), site=rep(names(z), sapply(z, nrow)))
     rownames(z) <- NULL
+  }else{
+    z$site <- ""
   }
   
+  
   if("qD.95.LCL" %in% names(z) == FALSE & se) {
     warning("invalid se setting, the iNEXT object do not consist confidence interval")
     se <- FALSE
@@ -736,65 +761,72 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
     if(levels(factor(z$order))>1 & "site"%in%names(z)){
       warning("invalid color.var setting, the iNEXT object consists multiple sites and orders, change setting as both")
       color.var <- "both"
-      z$col <- paste(z$site, z$order, sep="-")
+      z$col <- z$shape <- paste(z$site, z$order, sep="-")
+      
     }else if("site"%in%names(z)){
       warning("invalid color.var setting, the iNEXT object consists multiple orders, change setting as order")
       color.var <- "site"
-      z$col <- z$site
+      z$col <- z$shape <- z$site
     }else if(levels(factor(z$order))>1){
       warning("invalid color.var setting, the iNEXT object consists multiple sites, change setting as site")
       color.var <- "order"
-      z$col <- z$order
+      z$col <- z$shape <- factor(z$order)
     }else{
-      z$col <- rep(1, nrow(z))
+      z$col <- z$shape <- rep(1, nrow(z))
     }
   }else if(color.var=="order"){     
-    z$col <- z$order
+    z$col <- z$shape <- factor(z$order)
   }else if(color.var=="site"){
     if(!"site"%in%names(z)){
       warning("invalid color.var setting, the iNEXT object do not consist multiple sites, change setting as order")
-      z$col <- order
+      z$col <- z$shape <- factor(z$order)
     }
-    z$col <- z$site
+    z$col <- z$shape <- z$site
   }else if(color.var=="both"){
     if(!"site"%in%names(z)){
       warning("invalid color.var setting, the iNEXT object do not consist multiple sites, change setting as order")
-      z$col <- order
+      z$col <- z$shape <- factor(z$order)
     }
-    z$col <- paste(z$site, z$order, sep="-")
+    z$col <- z$shape <- paste(z$site, z$order, sep="-")
   }
   
   
-  
-  if("site"%in%names(z)){
-    g <- ggplot(z, aes(x=x, y=y, colour=factor(col))) + geom_point(aes(x=x, y=y, colour=factor(col)), size=5, data=subset(z, method=="observed"))
-  }else{
-    g <- ggplot(z, aes(x=x, y=y, colour=factor(col), shape=site)) + geom_point(aes(x=x, y=y, colour=factor(col), shape=site), size=5, data=subset(z, method=="observed"))
-  }
+  g <- ggplot(z, aes(x=x, y=y, colour=factor(col))) + 
+    geom_point(aes(shape=shape), size=5, data=subset(z, method=="observed"))
   
   g <- g + geom_line(aes(linetype=factor(method, c("interpolated", "extrapolated"), c("interpolation", "extrapolation"))), size=1.5) +
     guides(linetype=guide_legend(title="Method"), 
-           colour=guide_legend(title="Order"), 
-           fill=guide_legend(title="Order"), 
-           shape=guide_legend(title="Site")) + 
-    theme(legend.position = "bottom", text=element_text(size=18)) 
+           colour=guide_legend(title="Guides"), 
+           fill=guide_legend(title="Guides"), 
+           shape=guide_legend(title="Guides")) + 
+    theme(legend.position = "bottom", 
+          legend.title=element_blank(),
+          text=element_text(size=18)) 
   
-  if(type==2L) g <- g + labs(x="Number of sampling units", y="Sample coverage")
-  else if(type==3L) g <- g + labs(x="Sample coverage", y="Species diversity")
-  else g <- g + labs(x="Number of sampling units", y="Species diversity")
+  if(type==2L) {
+    g <- g + labs(x="Number of sampling units", y="Sample coverage")
+    if(names(x$DataInfo)[1]=="n") g <- g + labs(x="Number of individuals", y="Sample coverage")
+  }
+  else if(type==3L) {
+    g <- g + labs(x="Sample coverage", y="Species diversity")
+  }
+  else {
+    g <- g + labs(x="Number of sampling units", y="Species diversity")
+    if(names(x$DataInfo)[1]=="n") g <- g + labs(x="Number of individuals", y="Species diversity")
+  }
   
   if(se)
     g <- g + geom_ribbon(aes(ymin=y.lwr, ymax=y.upr, fill=factor(col), colour=NULL), alpha=0.2)
   
   
   if(facet.var=="order"){
-    if(length(levels(factor(z$order))) == 1){
+    if(length(levels(factor(z$order))) == 1 & type!=2){
       warning("invalid facet.var setting, the iNEXT object do not consist multiple orders.")      
     }else{
-      g <- g + facet_grid(.~ order)
+      g <- g + facet_wrap(~order, nrow=1)
       if(color.var=="both"){
-        g <- g + guides(colour=guide_legend(title="Site-Order", ncol=length(levels(factor(z$order))), byrow=TRUE),
-                        fill=guide_legend(title="Site-Order"))
+        g <- g + guides(colour=guide_legend(title="Guides", ncol=length(levels(factor(z$order))), byrow=TRUE),
+                        fill=guide_legend(title="Guides"))
       }
     }
   }
@@ -803,10 +835,10 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
     if(!"site"%in%names(z)) {
       warning("invalid facet.var setting, the iNEXT object do not consist multiple sites.")
     }else{
-      g <- g + facet_grid(.~site)
+      g <- g + facet_wrap(~site, nrow=1)
       if(color.var=="both"){
-        g <- g + guides(colour=guide_legend(title="Site-Order", nrow=length(levels(factor(z$order)))),
-                        fill=guide_legend(title="Site-Order"))
+        g <- g + guides(colour=guide_legend(title="Guides", nrow=length(levels(factor(z$order)))),
+                        fill=guide_legend(title="Guides"))
       }
     }
   }
@@ -817,16 +849,29 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
     }else{
       g <- g + facet_wrap(site~order) 
       if(color.var=="both"){
-        g <- g +  guides(colour=guide_legend(title="Site-Order", nrow=length(levels(factor(z$site))), byrow=TRUE),
-                         fill=guide_legend(title="Site-Order"))
+        g <- g +  guides(colour=guide_legend(title="Guides", nrow=length(levels(factor(z$site))), byrow=TRUE),
+                         fill=guide_legend(title="Guides"))
       }
     }
   }
+  
+  if(grey){
+    g <- g + theme_bw(base_size = 18) +
+      scale_fill_grey(start = 0, end = .4) +
+      scale_colour_grey(start = .2, end = .2) +
+      labs(x = "Number of individuals") +
+      guides(linetype=guide_legend(title="Method"), 
+             colour=guide_legend(title="Guides"), 
+             fill=guide_legend(title="Guides"), 
+             shape=guide_legend(title="Guides")) +
+      theme(legend.position="bottom",
+            legend.title=element_blank())
+  }
   return(g)
   
 }
 
-# Bug...
+# 
 # plot.iNEXT <- function(x, type=1, se=TRUE, show.legend=TRUE, show.main=TRUE, col=NULL,...){
 # 
 #   if(class(x) != "iNEXT") 
@@ -838,12 +883,16 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
 #   
 #   type <- pmatch(type, 1:3)
 #   
-#   y <- method <- site <- y.lwr <- y.upr <- NULL
+#   y <- method <- site <- shape <- y.lwr <- y.upr <- NULL
 #   site <<- NULL
+#   
 #   z <- x$Accumulation
 #   if(class(z) == "list"){
-#     z <- data.frame(do.call("rbind", z) ,site=rep(names(z), sapply(z, nrow)))
+#     z <- data.frame(do.call("rbind", z), site=rep(names(z), sapply(z, nrow)))
 #     rownames(z) <- NULL
+#   }else{
+#     z$site <- ""
+#     z$site <- factor(z$site)
 #   }
 #   
 #   if("qD.95.LCL" %in% names(z) == FALSE & se) {
@@ -858,7 +907,7 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
 #   if(type==1L) {
 #     z$x <- z[,1]
 #     z$y <- z$qD
-#     if(!is.null(xlab)) xlab <- "Number of sampling units"
+#     if(!is.null(xlab)) xlab <- ifelse(names(x$DataInfo)[1]=="n", "Number of individuals", "Number of sampling units")
 #     if(!is.null(ylab)) ylab <- "Species diversity"
 #     if(se){
 #       z$y.lwr <- z$qD.95.LCL
@@ -870,7 +919,7 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
 #     }
 #     z$x <- z[,1]
 #     z$y <- z$SC
-#     if(!is.null(xlab)) xlab <- "Number of sampling units"
+#     if(!is.null(xlab)) xlab <- ifelse(names(x$DataInfo)[1]=="n", "Number of individuals", "Number of sampling units")
 #     if(!is.null(ylab)) ylab <- "Sample coverage"
 #     if(se){
 #       z$y.lwr <- z$SC.95.LCL
@@ -900,12 +949,19 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
 #   }else{
 #     col <- rep(col,length(SITE))[1:length(SITE)]
 #   }
-#   
+#   pch <- (16+1:length(SITE))%%25  
 #   
 #   for(j in 1:length(ORDER)){
-#     tmp.j <- filter(z, order==ORDER[j]) %>% 
-#       select(site, order, method, x, y, y.lwr, y.upr)
-#     plot(y.upr~x, data=tmp.j, type="n", xlab="", ylab="", ...)
+#     if(se==TRUE){
+#       tmp.j <- filter(z, order==ORDER[j]) %>% 
+#         select(site, order, method, x, y, y.lwr, y.upr)
+#       plot(y.upr~x, data=tmp.j, type="n", xlab="", ylab="", ...)
+#     }else{
+#       tmp.j <- filter(z, order==ORDER[j]) %>% 
+#         select(site, order, method, x, y)
+#       plot(y~x, data=tmp.j, type="n", xlab="", ylab="", ...)
+#     }
+#     
 #     for(i in 1:length(SITE)){
 #       tmp <- filter(tmp.j, site==SITE[i])
 #       if(se==TRUE){
@@ -913,14 +969,14 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
 #       }
 #       lines(y~x, data=filter(tmp, method=="interpolated"), lty=1, lwd=2, col=col[i])
 #       lines(y~x, data=filter(tmp, method=="extrapolated"), lty=2, lwd=2, col=col[i])
-#       points(y~x, data=filter(tmp, method=="observed"), pch=19, lwd=2, col=col[i])
+#       points(y~x, data=filter(tmp, method=="observed"), pch=pch[i], cex=2, col=col[i])
 #       
 #     }
 #     if(show.legend==TRUE){
 #       if(type==3L){
-#         legend("topleft", legend=paste(level), col=col, lty=1, lwd=2, pch=19, bty="n")
+#         legend("topleft", legend=paste(SITE), col=col, lty=1, lwd=2, pch=pch, cex=1, bty="n")
 #       }else{
-#         legend("bottomright", legend=paste(level), col=col, lty=1, lwd=2, pch=19, bty="n")
+#         legend("bottomright", legend=paste(SITE), col=col, lty=1, lwd=2, pch=pch, cex=1, bty="n")
 #       }
 #     }
 #     title(xlab=xlab, ylab=ylab)
@@ -930,49 +986,52 @@ ggiNEXT <- function(x, type=1, se=TRUE, facet.var="none", color.var="order"){
 #   par(ask=FALSE)
 # }
 
+
+
+
 ##
 ##
 ###########################################
 ## Example individual-based data, spiders abundance data collected by Sackett et al. (2011)
 ##
 ##
-Girdled <- c(46, 22, 17, 15, 15, 9, 8, 6, 6, 4, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
-Logged <- c(88, 22, 16, 15, 13, 10, 8, 8, 7, 7, 7, 5, 4, 4, 4, 3, 3, 3, 3, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
-spider <- list(Girdled=Girdled, Logged=Logged)
-
-##
-##
-###########################################
-## Example sample-based data, tropical ant species data collected by Longino and Colwell (2011)
-## Note that first cell is number of total samples, and others are species incidence-based frequency.
-##
-
-## 50m
-y50 <- c(599,rep(1,49),rep(2,23),rep(3,18),rep(4,14),rep(5,9),rep(6,10),rep(7,4),
-         rep(8,8),rep(9,6),rep(10,2),rep(11,1),12,12,13,13,rep(14,5),15,15,
-         rep(16,4),17,17,17,18,18,19,19,20,20,20,21,22,23,23,25,27,27,29,30,30,
-         31,33,39,40,43,46,46,47,48,51,52,52,56,56,58,58,61,61,65,69,72,77,79,82,
-         83,84,86,91,95,97,98,98,106,113,124,126,127,128,129,129,182,183,186,195,
-         222,236,263,330)
-
-##500m
-y500 <- c(230,rep(1,71),rep(2,34),rep(3,12),rep(4,14),rep(5,9),rep(6,11),rep(7,8),
-          rep(8,4),rep(9,7),rep(10,5),rep(11,2),12,12,12,13,13,13,13,14,14,15,
-          16,16,17,17,17,17,18,19,20,21,21,23,24,25,25,25,26,27,30,31,31,32,32,
-          33,34,36,37,38,38,38,38,39,39,41,42,43,44,45,46,47,49,52,52,53,54,56,
-          60,60,65,73,78,123,131,133)
-
-##1070m
-y1070 <- c(150,rep(1,28),rep(2,16),rep(3,13),rep(4,3),rep(5,1),rep(6,3),rep(7,6),
-           rep(8,1),rep(9,1),rep(10,1),rep(11,4),12,12,12,13,13,13,13,14,15,
-           16,16,16,16,18,19,19,21,22,23,24,25,25,25,26,30,31,31,31,32,34,36,
-           38,39,43,43,45,45,46,54,60,68,74,80,96,99)
-##1500m
-y1500 <- c(200,rep(1,13),rep(2,4),rep(3,2),rep(4,2),rep(5,4),rep(6,2),rep(9,4),
-           rep(11,2),rep(17,2),18,19,23,23,24,25,25,25,29,30,32,33,43,50,53,
-           73,74,76,79,113,144)
-
-##2000m
-y2000=c(200,1,2,2,3,4,8,8,13,15,19,23,34,59,80)
-
-ant <- list(h50m=y50, h500m=y500, h1070m=y1070, h1500m=y1500, h2000m=y2000)
\ No newline at end of file
+# Girdled <- c(46, 22, 17, 15, 15, 9, 8, 6, 6, 4, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
+# Logged <- c(88, 22, 16, 15, 13, 10, 8, 8, 7, 7, 7, 5, 4, 4, 4, 3, 3, 3, 3, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
+# spider <- list(Girdled=Girdled, Logged=Logged)
+# 
+# ##
+# ##
+# ###########################################
+# ## Example sample-based data, tropical ant species data collected by Longino and Colwell (2011)
+# ## Note that first cell is number of total samples, and others are species incidence-based frequency.
+# ##
+# 
+# ## 50m
+# y50 <- c(599,rep(1,49),rep(2,23),rep(3,18),rep(4,14),rep(5,9),rep(6,10),rep(7,4),
+#          rep(8,8),rep(9,6),rep(10,2),rep(11,1),12,12,13,13,rep(14,5),15,15,
+#          rep(16,4),17,17,17,18,18,19,19,20,20,20,21,22,23,23,25,27,27,29,30,30,
+#          31,33,39,40,43,46,46,47,48,51,52,52,56,56,58,58,61,61,65,69,72,77,79,82,
+#          83,84,86,91,95,97,98,98,106,113,124,126,127,128,129,129,182,183,186,195,
+#          222,236,263,330)
+# 
+# ##500m
+# y500 <- c(230,rep(1,71),rep(2,34),rep(3,12),rep(4,14),rep(5,9),rep(6,11),rep(7,8),
+#           rep(8,4),rep(9,7),rep(10,5),rep(11,2),12,12,12,13,13,13,13,14,14,15,
+#           16,16,17,17,17,17,18,19,20,21,21,23,24,25,25,25,26,27,30,31,31,32,32,
+#           33,34,36,37,38,38,38,38,39,39,41,42,43,44,45,46,47,49,52,52,53,54,56,
+#           60,60,65,73,78,123,131,133)
+# 
+# ##1070m
+# y1070 <- c(150,rep(1,28),rep(2,16),rep(3,13),rep(4,3),rep(5,1),rep(6,3),rep(7,6),
+#            rep(8,1),rep(9,1),rep(10,1),rep(11,4),12,12,12,13,13,13,13,14,15,
+#            16,16,16,16,18,19,19,21,22,23,24,25,25,25,26,30,31,31,31,32,34,36,
+#            38,39,43,43,45,45,46,54,60,68,74,80,96,99)
+# ##1500m
+# y1500 <- c(200,rep(1,13),rep(2,4),rep(3,2),rep(4,2),rep(5,4),rep(6,2),rep(9,4),
+#            rep(11,2),rep(17,2),18,19,23,23,24,25,25,25,29,30,32,33,43,50,53,
+#            73,74,76,79,113,144)
+# 
+# ##2000m
+# y2000=c(200,1,2,2,3,4,8,8,13,15,19,23,34,59,80)
+# 
+# ant <- list(h50m=y50, h500m=y500, h1070m=y1070, h1500m=y1500, h2000m=y2000)
\ No newline at end of file
